#ifndef H_FASTFILE
#define H_FASTFILE
/*
 * fastfile.h
 *
 * Definition file for my fast I/O functions
 */

#if defined(__TOS__) && !defined(__TOS)
#include <tos.h>
#endif

/*
 * Default Buffer Size
 */

#ifdef __TOS__
#define BUFFERSIZE 0x8000L
#define READBUFFERSIZE 0x8000L
#define WRITEBUFFERSIZE 0x2000L
#else
#define BUFFERSIZE 0x8000	/* Lets have a bigger buffer! */
#define READBUFFERSIZE 0x8000
#define WRITEBUFFERSIZE 0x1000
#endif

/*
 * the main structure
 */

typedef struct s_fastfile {
	struct s_fastfile *next;
	int fp;
	int mode;
	struct {
		int eof:1;
		int eol:1;
		int finished:1;
		int cooked:1;	/* Set to translate CR/LF */
	} flags;
	int error;
	size_t bufsize;
	char *bufstart;
	char *bufend;
	char *pos;
} FASTFILE;

/*
 * Error return values
 */
 
typedef enum {
	FE_OK,
	FE_NOHANDLE,
	FE_WRITE_ERROR,
	FE_READ_ERROR
} FE_ERROR;

/*
 * Some definitions to make it easy to use
 */

#define FF_READ		0x0000	/* Open for read only */
#define FF_WRITE 	0x0001	/* Open in create/write mode */
#define FF_RAW		0x0000	/* No translations */
#define FF_COOKED	0x0002	/* Translate CR/LF */


/*
 * Function Prototypes
 */

FASTFILE *fastopen(char *name, int mode, size_t size);
FE_ERROR fastclose(FASTFILE *file);
char *fastgets(char *buf, int length, FASTFILE *file);
char *fastreads(FASTFILE *file);
FE_ERROR fastputs(char *s, FASTFILE *file);
FE_ERROR fastwrite(FASTFILE *file, void *ad, size_t length);
int copyfile(char *srcname, char *destname);

#endif

